<?php
    /**
     * ReduxFramework Tr Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }


    // This is your option name where all the Redux data is stored.
    $opt_name = "trconf";

    /*
     *
     * --> Action hook examples
     *
     */

    // If Redux is running as a plugin, this will remove the demo notice and links
    add_action( 'redux/loaded', 'remove_demo' );

    // Function to test the compiler hook and demo CSS output.
    // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
    add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);


    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    load_theme_textdomain(TR_THEMENAMEOPTIONS, get_template_directory().'/languages/admin/');

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        'disable_tracking' => true,
        'show_hints' => false,
        'dismiss' => false,
        'hint' => false,
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => false,
        // Show the sections below the admin menu item or not
        'menu_title'           => __( 'Options', TR_THEMENAMEOPTIONS ),
        'page_title'           => __( 'Options', TR_THEMENAMEOPTIONS ),
        // You will need to generate a Google API key to use this feature.
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => true,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => false,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        'page_type' => 'submenu',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        'footer_credit'     => '<a href="#">ToroThemes</a>',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'system_info'          => false,
    );

    // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
    $args['share_icons'][] = array(
        'url'   => 'http://twitter.com/torothemes',
        'title' => __( 'Follow us on Twitter', TR_THEMENAMEOPTIONS ),
        'icon'  => 'el el-twitter'
    );

    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['opt_name'] );
        }
        $args['intro_text'] = '';
    } else {
        $args['intro_text'] = '';
    }

    // Add content after the form.
    $args['footer_text'] = '';

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     *
     * ---> START SECTIONS
     *
     */

    Redux::setSection( $opt_name, array(
        'title' => __( 'General', TR_THEMENAMEOPTIONS ),
        'id'    => 'general',
        'desc'  => __( '', TR_THEMENAMEOPTIONS ),
        'icon'  => 'el el-home',
        'fields'     => array(
            array(
                'id'       => 'speed',
                'type'     => 'switch',
                'title'    => __( 'Faster loading', TR_THEMENAMEOPTIONS ),
                'default'  => 0,
                'on'       => __( 'Enabled', TR_THEMENAMEOPTIONS ),
                'off'      => __( 'Disable', TR_THEMENAMEOPTIONS ),
                'desc' => __('Requires W3 Total Cache configured as indicated in the manual.', TR_THEMENAMEOPTIONS )
            ),
            array(
                'id'       => 'email',
                'type'     => 'text',
                'validate' => 'email',
                'title'    => __( 'Email', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'Please enter a valid email.', TR_THEMENAMEOPTIONS ),
                'default'  => get_option('admin_email')
            ),
            array(
                'id'      => 'post_per_page',
                'type'    => 'spinner',
                'title'   => __( 'Number of videos per page', TR_THEMENAMEOPTIONS ),
                'default' => 18,
                'min'     => '1',
                'step'    => '1',
                'max'     => '100',
            ),
            array(
                'id'      => 'post_per_related',
                'type'    => 'spinner',
                'title'   => __( 'Number of related videos', TR_THEMENAMEOPTIONS ),
                'default' => 8,
                'min'     => '1',
                'step'    => '1',
                'max'     => '100',
            ),
            array(
                'id'      => 'post_per_categories',
                'type'    => 'spinner',
                'title'   => __( 'Number of categories to display on homepage', TR_THEMENAMEOPTIONS ),
                'desc' => __('0 to hide in the home', TR_THEMENAMEOPTIONS), 
                'default' => 12,
                'min'     => '0',
                'step'    => '1',
                'max'     => '100',
            ),
            array(
                'id'       => 'page_categories',
                'type'     => 'select',
                'data'     => 'pages',
                'title'    => __( 'Page to see all categories', TR_THEMENAMEOPTIONS ),
            ),
            array(
                'id'       => 'twitter',
                'type'     => 'text',
                'validate' => 'url',
                'title'    => __( 'Twitter', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'Enter the URL of your Twitter. (Leave blank if none)', TR_THEMENAMEOPTIONS ),
                'default'  => 'http://twitter.com/torothemes'
            ),
            array(
                'id'       => 'fieldvideo',
                'type'     => 'text',
                'validate' => 'no_html',
                'title'    => __( 'Video custom field', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'Modify it if necessary. (Optional)', TR_THEMENAMEOPTIONS ),
                'default'  => 'video'
            ),
            array(
                'id'       => 'fieldtime',
                'type'     => 'text',
                'validate' => 'no_html',
                'title'    => __( 'Duration custom field', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'Modify it if necessary. (Optional)', TR_THEMENAMEOPTIONS ),
                'default'  => 'duration'
            ),
            array(
                'id'      => 'textfooter',
                'type'    => 'editor',
                'title'   => __( 'Footer text', TR_THEMENAMEOPTIONS ),
                'default' => __('To prevent the entry of minors, this site has been labeled by RTA (Restricted To Adults, restricted to adults, in Spanish). You can easily block access to this site by a filter navigation.', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 5,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'=>'custom_header_code',
                'type' => 'textarea',
                'title' => __( 'Header code', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'Enter special code. ( e.g.: Mochi Verification).', TR_THEMENAMEOPTIONS ),
                'default' => ''
            ),

            array(
                'id'=>'custom_footer_code',
                'type' => 'textarea',
                'title' => __( 'Footer code', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'Enter special code. ( e.g.: Mochi Verification).', TR_THEMENAMEOPTIONS ),
                'default' => ''
            ),
        ),
    ) );

   Redux::setSection( $opt_name, array(
        'title' => __( 'SEO', TR_THEMENAMEOPTIONS ),
        'id'    => 'seo',
        'desc'  => __( '', TR_THEMENAMEOPTIONS ),
        'icon'  => 'el el-font'
    ) );

    Redux::setSection( $opt_name, array(
        'title'      => __( 'H1', TR_THEMENAMEOPTIONS ),
        'id'         => 'h1',
        'subsection' => true,
        'desc'       => '',
        'fields'     => array(
            array(
                'id'      => 'h1_home',
                'type'    => 'editor',
                'title'   => __( 'HomePage', TR_THEMENAMEOPTIONS ),
                'default' => __('XXX Porn Free for all', TR_THEMENAMEOPTIONS ),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'h1_category',
                'type'    => 'editor',
                'title'   => __( 'Category', TR_THEMENAMEOPTIONS ),
                'default' => __('Porn Videos {name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the name of the category', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'h1_post',
                'type'    => 'editor',
                'title'   => __( 'Post', TR_THEMENAMEOPTIONS ),
                'default' => __('{name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the name of the entry', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'h1_search',
                'type'    => 'editor',
                'title'   => __( 'Search', TR_THEMENAMEOPTIONS ),
                'default' => __('Search video {name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the search', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'h1_tag',
                'type'    => 'editor',
                'title'   => __( 'Tag', TR_THEMENAMEOPTIONS ),
                'default' => __('Tag video {name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the name of the tag', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'h1_page',
                'type'    => 'editor',
                'title'   => __( 'Page', TR_THEMENAMEOPTIONS ),
                'default' => __('{name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the title of the page', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'      => __( 'H2', TR_THEMENAMEOPTIONS ),
        'id'         => 'h2',
        'subsection' => true,
        'desc'       => '',
        'fields'     => array(
            array(
                'id'      => 'h2_home',
                'type'    => 'editor',
                'title'   => __( 'HomePage', TR_THEMENAMEOPTIONS ),
                'default' => sprintf( __('LAST %sPORNO MOVIES%s', TR_THEMENAMEOPTIONS), '<strong>', '</strong>'),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'h2_category',
                'type'    => 'editor',
                'title'   => __( 'Category', TR_THEMENAMEOPTIONS ),
                'default' => __('Porn Videos {name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the name of the category', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'h2_post',
                'type'    => 'editor',
                'title'   => __( 'Post', TR_THEMENAMEOPTIONS ),
                'default' => __('{name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the name of the entry', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'h2_search',
                'type'    => 'editor',
                'title'   => __( 'Search', TR_THEMENAMEOPTIONS ),
                'default' => __('Search video {name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the search', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'h2_tag',
                'type'    => 'editor',
                'title'   => __( 'Tag', TR_THEMENAMEOPTIONS ),
                'default' => __('Tag video {name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the name of the tag', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'h2_page',
                'type'    => 'editor',
                'title'   => __( 'Page', TR_THEMENAMEOPTIONS ),
                'default' => __('{name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the title of the page', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'h2_categories',
                'type'    => 'editor',
                'title'   => __( 'Title page categories', TR_THEMENAMEOPTIONS ),
                'default' => __('Categories', TR_THEMENAMEOPTIONS ),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'h2_related',
                'type'    => 'editor',
                'title'   => __( 'Title related', TR_THEMENAMEOPTIONS ),
                'default' => sprintf( __('%sPorn videos%s related {name}', TR_THEMENAMEOPTIONS), '<strong>', '</strong>'),
                'desc' => __('{name} to display the category post', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'      => __( 'Description', TR_THEMENAMEOPTIONS ),
        'id'         => 'description',
        'subsection' => true,
        'desc'       => '',
        'fields'     => array(
            array(
                'id'      => 'category_desc',
                'type'    => 'editor',
                'title'   => __( 'Category', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( '{name} to display the name of the category<br>{total} to display the number of posts in the category', TR_THEMENAMEOPTIONS ),
                'default' => sprintf( __('Enjoy over %s{total}%s videos on %s{name}%s. We have thousands of XXX videos dedicated to %s{name}%s. Learn about online videos on %s{name}%s Fuck me in here. Videos of %s{name}%s XXX doing all sorts of dirty tricks, free.', TR_THEMENAMEOPTIONS), '<strong>', '</strong>', '<strong>', '</strong>', '<strong>', '</strong>', '<strong>', '</strong>', '<strong>', '</strong>'),
                'desc' => __('Leave blank if you do not want to leave the description, if you want to customize it to the 100% category edit and put a description.', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'tag_desc',
                'type'    => 'editor',
                'title'   => __( 'Tag', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( '{name} to display the name of the tag<br>{total} to display the number of posts in the category', TR_THEMENAMEOPTIONS ),
                'default' => sprintf( __('Enjoy over %s{total}%s videos on %s{name}%s. We have thousands of XXX videos dedicated to %s{name}%s. Learn about online videos on %s{name}%s Fuck me in here. Videos of %s{name}%s XXX doing all sorts of dirty tricks, free.', TR_THEMENAMEOPTIONS), '<strong>', '</strong>', '<strong>', '</strong>', '<strong>', '</strong>', '<strong>', '</strong>', '<strong>', '</strong>'),
                'desc' => __('Leave blank if you do not want to leave the description, if you want to customize it to the 100% tag edit and put a description.', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title' => __( 'Advertising', TR_THEMENAMEOPTIONS ),
        'id'    => 'ads',
        'desc'  => __( '', TR_THEMENAMEOPTIONS ),
        'icon'  => 'el el-list-alt',
        'fields'     => array(

            array(
                'id'=>'ads_ft',
                'type' => 'textarea',
                'title' => __( 'Advertising footer', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'To add more than one block of advertising, adding one per line. 300x250', TR_THEMENAMEOPTIONS ),
                'default' => '<img src="'.get_template_directory_uri().'/img/bnr.png" alt="bnr">'."\r\n".'<img src="'.get_template_directory_uri().'/img/bnr.png" alt="bnr">'."\r\n".'<img src="'.get_template_directory_uri().'/img/bnr.png" alt="bnr">'."\r\n".'<img src="'.get_template_directory_uri().'/img/bnr.png" alt="bnr">',
            ),
            array(
                'id'=>'ads_lst',
                'type' => 'textarea',
                'title' => __( 'List of advertising posts', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( '300x250', TR_THEMENAMEOPTIONS ),
                'default' => '<img src="'.get_template_directory_uri().'/img/bnr.png" alt="bnr">',
            ),
            array(
                'id'=>'ads_post',
                'type' => 'textarea',
                'title' => __( 'Advertising post', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'To add more than one block of advertising, adding one per line. 300x250', TR_THEMENAMEOPTIONS ),
                'default' => '<img src="'.get_template_directory_uri().'/img/bnr.png" alt="bnr">'."\r\n".'<img src="'.get_template_directory_uri().'/img/bnr.png" alt="bnr">'."\r\n".'<img src="'.get_template_directory_uri().'/img/bnr.png" alt="bnr">'."\r\n".'<img src="'.get_template_directory_uri().'/img/bnr.png" alt="bnr">',
            ),
        ),
    ) );

   Redux::setSection( $opt_name, array(
        'title' => __( 'Design', TR_THEMENAMEOPTIONS ),
        'id'    => 'mtdesign',
        'desc'  => __( '', TR_THEMENAMEOPTIONS ),
        'icon'  => 'el el-font'
    ) );

    Redux::setSection( $opt_name, array(
        'title' => __( 'General', TR_THEMENAMEOPTIONS ),
        'id'    => 'generaldesign',
        'subsection' => true,
        'desc'  => __( '', TR_THEMENAMEOPTIONS ),
        'fields'     => array(
            array(
                'id'       => 'logo',
                'type'     => 'media',
                'url'      => true,
                'title'    => __( 'Logo', TR_THEMENAMEOPTIONS ),
                'compiler' => 'false',
                'default'  => array( 'url' => get_template_directory_uri().'/img/logo.png' ),
            ),
            array(
                'id'       => 'favicon',
                'type'     => 'media',
                'url'      => true,
                'title'    => __( 'Favicon', TR_THEMENAMEOPTIONS ),
                'compiler' => 'false',
                'default'  => array( 'url' => get_template_directory_uri().'/img/icon.png' ),
            ),
            array(
                'id'       => 'sidebar',
                'type'     => 'switch',
                'title'    => __( 'Show Sidebar', TR_THEMENAMEOPTIONS ),
                'default'  => 2,
                'on'       => __( 'Enabled', TR_THEMENAMEOPTIONS ),
                'off'      => __( 'Disable', TR_THEMENAMEOPTIONS ),
            ),
            array(
                'id'       => 'layout',
                'type'     => 'switch',
                'title'    => __( 'Layout', TR_THEMENAMEOPTIONS ),
                'default'  => 1,
                'on'       => __( 'Tube', TR_THEMENAMEOPTIONS ),
                'off'      => __( 'Blog', TR_THEMENAMEOPTIONS ),
            ),
            array(
                'id'       => 'info',
                'type'     => 'switch',
                'title'    => __( 'Show information', TR_THEMENAMEOPTIONS ),
                'default'  => 1,
                'on'       => __( 'Enabled', TR_THEMENAMEOPTIONS ),
                'off'      => __( 'Disable', TR_THEMENAMEOPTIONS ),
                'required' => array('layout','equals','1')
            ),
            array(
                'id'      => 'characters_info',
                'type'    => 'spinner',
                'title'   => __( 'Number of characters in button info', TR_THEMENAMEOPTIONS ),
                'default' => 480,
                'min'     => '1',
                'step'    => '1',
                'max'     => '1000',
                'required' => array('info','equals','1')
            ),
            array(
                'id'       => 'menulinks',
                'type'     => 'switch',
                'title'    => __( 'Show menu list of links in posts', TR_THEMENAMEOPTIONS ),
                'default'  => 1,
                'on'       => __( 'Enabled', TR_THEMENAMEOPTIONS ),
                'off'      => __( 'Disable', TR_THEMENAMEOPTIONS ),
                'required' => array('layout','equals','1')
            ),
            array(
                'id'       => 'comments',
                'type'     => 'switch',
                'title'    => __( 'Show comments', TR_THEMENAMEOPTIONS ),
                'default'  => 2,
                'on'       => __( 'Enabled', TR_THEMENAMEOPTIONS ),
                'off'      => __( 'Disable', TR_THEMENAMEOPTIONS ),
            ),
            array(
                'id'       => 'lazy',
                'type'     => 'switch',
                'title'    => __( 'Lazy load', TR_THEMENAMEOPTIONS ),
                'default'  => 1,
                'on'       => __( 'Enabled', TR_THEMENAMEOPTIONS ),
                'off'      => __( 'Disable', TR_THEMENAMEOPTIONS ),
            ),
            ),
    ));

    Redux::setSection( $opt_name, array(
        'title' => __( 'Colors', TR_THEMENAMEOPTIONS ),
        'id'    => 'colors',
        'subsection' => true,
        'desc'  => __( '', TR_THEMENAMEOPTIONS ),
        'fields'     => array(
            array(
                'id'       => 'css',
                'type'     => 'switch',
                'title'    => __( 'CSS Custom', TR_THEMENAMEOPTIONS ),
                'default'  => 2,
                'on'       => __( 'Enabled', TR_THEMENAMEOPTIONS ),
                'off'      => __( 'Disable', TR_THEMENAMEOPTIONS ),

            ),
            array(
                'id'       => 'c1',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( '01 Color background site', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #fff.', TR_THEMENAMEOPTIONS ),
                'default'  => '#fff',
                'transparent' => false,
                'required' => array('css','equals','1'),
                'compiler' => array('.c1')
            ),
            array(
                'id'       => 'c2',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( '02 Color text in general', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #999.', TR_THEMENAMEOPTIONS ),
                'default'  => '#999',
                'transparent' => false,
                'required' => array('css','equals','1'),
                'compiler' => array('.c2')
            ),
            array(
                'id'       => 'c3',
                'type'     => 'link_color',
                'title'    => __( '03 Color of Links', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'Default: #666 / #fa6295', TR_THEMENAMEOPTIONS ),
                'active'    => false,
                'default'  => array(
                    'regular' => '#666',
                    'hover'   => '#fa6295',
                ),
                'required' => array('css','equals','1'),
                'compiler' => array('.c3')
            ),
            array(
                'id'       => 'c4',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( '04 General Color (Pink)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #fa6295.', TR_THEMENAMEOPTIONS ),
                'default'  => '#fa6295',
                'transparent' => false,
                'required' => array('css','equals','1'),
                'compiler' => array('.c4')
            ),
            array(
                'id'       => 'c5',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( '05 Text information', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #fff7fa.', TR_THEMENAMEOPTIONS ),
                'default'  => '#fff7fa',
                'transparent' => false,
                'required' => array('css','equals','1'),
                'compiler' => array('.c5')
            ),
            array(
                'id'       => 'c6',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( '06 Color menu icons and titles', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #fcb0ca.', TR_THEMENAMEOPTIONS ),
                'default'  => '#fcb0ca',
                'transparent' => false,
                'required' => array('css','equals','1'),
                'compiler' => array('.c6')
            ),
            array(
                'id'       => 'c7',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( '07 Color advertising icon', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #673bb7.', TR_THEMENAMEOPTIONS ),
                'default'  => '#673bb7',
                'transparent' => false,
                'required' => array('css','equals','1'),
                'compiler' => array('.c7')
            ),
            array(
                'id'       => 'c8',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( '08 Border color separator', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #fff7fa.', TR_THEMENAMEOPTIONS ),
                'default'  => '#fff7fa',
                'transparent' => false,
                'required' => array('css','equals','1'),
                'compiler' => array('.c8')
            ),
            array(
                'id'        => 'mt-css-custom',
                'type'      => 'ace_editor',
                'title'     => __('Custom CSS', TR_THEMENAMEOPTIONS),
                'subtitle'  => __('Quickly add some CSS to your theme by adding it to this block.', TR_THEMENAMEOPTIONS),
                'mode'      => 'css',
                'theme'     => 'monokai',
                'default'   => "",
                'required' => array('css','equals','1'),
            ),
        ),
    ) );

    Redux::setSection( $opt_name, array(
        'title' => __( 'License', TR_THEMENAMEOPTIONS ),
        'id'    => 'license',
        'desc'  => __( '', TR_THEMENAMEOPTIONS ),
        'icon'  => 'el el-thumbs-up',
        'fields'     => array(
            array(
                'id'       => 'license',
                'type'     => 'callback',
                'title'    => __('Enter your license', TR_THEMENAMEOPTIONS ),
                'callback' => 'redux_license'
            ),
        ),
    ) );

    if ( file_exists( dirname( __FILE__ ) . '/../README.md' ) ) {
        $section = array(
            'icon'   => 'el el-list-alt',
            'title'  => __( 'Documentation', TR_THEMENAMEOPTIONS ),
            'fields' => array(
                array(
                    'id'       => '17',
                    'type'     => 'raw',
                    'markdown' => true,
                    'content'  => file_get_contents( dirname( __FILE__ ) . '/../README.md' )
                ),
            ),
        );
        Redux::setSection( $opt_name, $section );
    }
    /*
     * <--- END SECTIONS
     */

    function compiler_action( $options, $css, $changed_values ) {
        global $wp_filesystem;
 
        $filename = get_stylesheet_directory(). '/create.css';

        if( empty( $wp_filesystem ) ) {
            require_once( ABSPATH .'/wp-admin/includes/file.php' );
            WP_Filesystem();
        }
                
        $css='';
        if($options['c1']==''){$options['c1']='#fff';}
        if($options['c2']==''){$options['c2']='#999';}
        if($options['c3']['regular']==''){$options['c3']['regular']='#666';}
        if($options['c3']['hover']==''){$options['c3']['hover']='#fa6295';}
        if($options['c4']==''){$options['c4']='#fa6295';}
        if($options['c5']==''){$options['c5']='#fff7fa';}
        if($options['c6']==''){$options['c6']='#fcb0ca';}
        if($options['c7']==''){$options['c7']='#673bb7';}
        if($options['c8']==''){$options['c8']='#fff7fa';}
        
        $css.='body{background-color:'.$options['c1'].'}'."\r";
        $css.='body{color:'.$options['c2'].'}'."\r";
        $css.='a,.ttl-cn,.wp-pagenavi a.page{color:'.$options['c3']['regular'].'}'."\r";
        $css.='@media (max-width: 999px){
            .sub-menu li.btn-vts a{color:'.$options['c3']['regular'].'}
        }'."\r";
        $css.='a:hover,.ctg-txt strong{color:'.$options['c3']['hover'].'}'."\r";
        $css.='::-webkit-scrollbar-thumb{background-color:'.$options['c4'].'}
.cookie-notice-container a.button,[class*="btn-"]:hover,[class*="btn-"]:hover>a,button:hover,input[type="button"]:hover,input[type="reset"]:hover,input[type="submit"]:hover,.tagcloud a:hover,.wp-pagenavi a:hover,.wp-pagenavi span.current,.ftc,.ctg-cls div.fa-film:before,.percnt>div,.psrcmd>i{background-color:'.$options['c4'].'}
.pst-cn:hover figure,.pst-cn:hover header{background-color: '.$options['c4'].';}
[class*="btn-"],button,input[type="button"],input[type="reset"],input[type="submit"],.tagcloud a,.wp-pagenavi a,.wp-pagenavi span{border:1px solid '.$options['c4'].'}
.chk [type="checkbox"]:checked+i:before,.chk [type="radio"]:checked+i:before{border-color:'.$options['c4'].'}
.chk [type="checkbox"]:checked+i:before,.chk [type="radio"]:checked+i:before,.tagcloud a,.wp-pagenavi a,.wp-pagenavi span{color:'.$options['c4'].'}
.pst-cn:hover figure,.pst-cn:hover header{box-shadow: 0 0 0 5px '.$options['c4'].'}
[class*="btn-"],[class*="btn-"]>a,button,input[type="button"],input[type="reset"],input[type="submit"],.frm-srch button:hover,.ctg-cls div.fa-film strong,.numper strong{color:'.$options['c4'].'}
.mn-hd li:hover:before{color:'.$options['c4'].'}
@media (max-width: 999px){
	.sub-menu li.btn-vts a:hover{color:'.$options['c4'].'}
}
@media (max-width: 749px){
	section.pst-cn figure,section.pst-cn header{background-color: '.$options['c4'].';}
}'."\r";
        $css.='.ctg-txt{background-color: '.$options['c5'].';}';
        $css.='.mn-hd li:before,.ttl-cn:before,.frm-srch h1,.ctgtgs p:before,.lst-shr li:before{color:'.$options['c6'].'}';
        $css.='.lst-lnk li:before{color: '.$options['c7'].';}';
        $css.='input,textarea,select,.lst-lnk,.ctg-img img,.vdnf{border:2px solid '.$options['c8'].'}'."\r";
        $css.='.btspr{border-top: 2px solid '.$options['c8'].';padding-top:15px}'."\r";
        $css.="::-webkit-scrollbar{background-color:rgba(0,0,0,.2)}"."\r";
        $css.='input,textarea,select,.slc label,.chk [type="checkbox"]+i:before,.chk [type="radio"]+i:before{background-color:#FFF}
        input:disabled,textarea:disabled,select:disabled{background-color:#eee}
        .chk [type="checkbox"]:disabled+i:before,.chk [type="radio"]:disabled+i:before{background-color:#eee}
        [class*="btn-"],[class*="btn-"]>a,button,input[type="button"],input[type="reset"],input[type="submit"]{background-color:#fff}
        .mn-hd{background-color: rgba(0,0,0,.7);}
        @media (max-width: 749px){
            .pst-cn header,.pst-cn header a{color: #fff;}	
        }
        @media (max-width: 999px){
            .mn-hd>ul{background-color: rgba(255,255,255,.9);}
        }
        @media (min-width: 1000px){
            .mn-hd{background-color: transparent;}
        }
        input:disabled,textarea:disabled,select:disabled{border-color:#ddd}
        .frm-scc input,.frm-scc textarea,.frm-scc select{border-color:#24c970}
        .frm-wrn input,.frm-wrn textarea,.frm-wrn select{border-color:#f09941}
        .frm-rrr input,.frm-rrr textarea,.frm-rrr select{border-color:#f24343}
        .chk [type="checkbox"]+i:before,.chk [type="radio"]+i:before{border:1px solid #f1f1f1}
        .chk [type="checkbox"]:disabled+i:before,.chk [type="radio"]:disabled+i:before{border-color:#ddd}
        [class*="btn-"]:hover,[class*="btn-"]:hover a,button:hover,input[type="button"]:hover,input[type="reset"]:hover,input[type="submit"]:hover,.tagcloud a:hover,.wp-pagenavi a:hover,.wp-pagenavi span.current,.ftc,.ftc a,.ctg-cls div.fa-film:before{color:#fff}
        .chk [type="checkbox"]:disabled+i:before,.chk [type="radio"]:disabled+i:before{color:#999}
        .frm-scc>label{color:#24c970}
        .frm-wrn>label{color:#f09941}
        .frm-rrr>label{color:#f24343}
        .pst-cn:hover header,.pst-cn:hover header a,.psrcmd>i{color: #fff;}
        .ftb{color: #aaa;}'."\r";
        $css.=$options['mt-css-custom']."\r";
        
        if( $wp_filesystem ) {
            $wp_filesystem->put_contents(
                $filename,
                $css,
                FS_CHMOD_FILE // predefined mode settings for WP files
            );
        }
        echo 'hola?';
    }

    if ( ! function_exists( 'redux_license' ) ) {
        function redux_license( $field, $value ) {
            if(get_option('mtlicense')!=''){
                echo '<p><input class="regular-text" name="mt_activation_text" type="text" value="'.get_option('mtlicense').'" placeholder="'.__( 'Enter your license', TR_THEMENAMEOPTIONS ).'"><button name="mt_activation_bt" type="button" class="button button-primary" data-txt="'.__('Check', TR_THEMENAMEOPTIONS).'">'.__('Check', TR_THEMENAMEOPTIONS).'</button></p><span id="mt_activation">'.__('License activated properly.', TR_THEMENAMEOPTIONS).'</span>';            
            }else{
                echo '<p><input class="regular-text" name="mt_activation_text" type="text" placeholder="'.__( 'Enter your license', TR_THEMENAMEOPTIONS ).'"><button name="mt_activation_bt" type="button" class="button button-primary" data-txt="'.__('Check', TR_THEMENAMEOPTIONS).'">'.__('Check', TR_THEMENAMEOPTIONS).'</button></p><span id="mt_activation"></span>';
            }
        }
    }

    function remove_demo() {

        // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
        if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
            remove_filter( 'plugin_row_meta', array(
                ReduxFrameworkPlugin::instance(),
                'plugin_metalinks'
            ), null, 2 );

            // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
            remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
    }
    
    add_action( 'admin_menu', 'remove_redux_menu',12 );
    
    function remove_redux_menu() {
        remove_submenu_page('tools.php','redux-about');
    }
}
