<?php
/**
 * Plugin installation and activation for WordPress themes.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage ToroTube
 * @version    2.4.0
 * @author     Thomas Griffin <thomasgriffinmedia.com>
 * @author     Gary Jones <gamajo.com>
 * @copyright  Copyright (c) 2014, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/thomasgriffin/TGM-Plugin-Activation
 */

/**
 * Include the TGM_Plugin_Activation class.
 */
require_once dirname( __FILE__ ) . '/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'mt_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function mt_register_required_plugins() {
		
	load_theme_textdomain(TR_THEMENAMEOPTIONS, get_template_directory().'/languages/admin/');
	load_theme_textdomain('tgmpa', get_template_directory().'/languages/admin/');

    /**
     * Array of plugin arrays. Required keys are name and slug.
     * If the source is NOT from the .org repo, then source is also required.
     */
    $plugins = array(

        array(
            'name'      => 'WP-PageNavi',
            'slug'      => 'wp-pagenavi',
            'required'  => true,
        ),

        array(
            'name'      => 'WP-PostViews',
            'slug'      => 'wp-postviews',
            'required'  => true,
        ),
        
        array(
            'name'      => 'Categories Images',
            'slug'      => 'categories-images',
            'required'  => true,
        ),
        
        array(
            'name'      => 'Cookie Notice by dFactory',
            'slug'      => 'cookie-notice',
            'required'  => false,
        ),

        array(
            'name'      => 'Contact Form 7',
            'slug'      => 'contact-form-7',
            'required'  => false,
        ),
        
        array(
            'name'      => 'W3 Total Cache',
            'slug'      => 'w3-total-cache',
            'required'  => false,
        ),
        
		array(
			'name'               => 'ToroAPI', // The plugin name.
			'slug'               => 'toroapi', // The plugin slug (typically the folder name).
			'source'             => 'http://torothemes.com/api/wp/toroapi.zip', // The plugin source.
			'required'           => false, // If false, the plugin is only 'recommended' instead of required.
			'version'            => '1.0', // E.g. 1.0.0. If set, the active plugin must be this version or higher. If the plugin version is higher than the plugin version installed, the user will be notified to update the plugin.
			'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
			'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
			'external_url'       => '', // If set, overrides default API URL and points to an external URL.
		),
        
    );

    /**
     * Array of configuration settings. Amend each line as needed.
     * If you want the default strings to be available under your own theme domain,
     * leave the strings uncommented.
     * Some of the strings are added into a sprintf, so see the comments at the
     * end of each line for what each argument will be.
     */
    $config = array(
        'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'mt-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        'strings'      => array(
            'page_title'                      => __( 'Install Required Plugins', TR_THEMENAMEOPTIONS),
            'menu_title'                      => __( 'Install Plugins', TR_THEMENAMEOPTIONS),
            'installing'                      => __( 'Installing Plugin: %s', TR_THEMENAMEOPTIONS), // %s = plugin name.
            'oops'                            => __( 'Something went wrong with the plugin API.', TR_THEMENAMEOPTIONS),
            'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', TR_THEMENAMEOPTIONS), // %1$s = plugin name(s).
            'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', TR_THEMENAMEOPTIONS), // %1$s = plugin name(s).
            'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', TR_THEMENAMEOPTIONS), // %1$s = plugin name(s).
            'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', TR_THEMENAMEOPTIONS), // %1$s = plugin name(s).
            'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', TR_THEMENAMEOPTIONS), // %1$s = plugin name(s).
            'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', TR_THEMENAMEOPTIONS), // %1$s = plugin name(s).
            'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', TR_THEMENAMEOPTIONS), // %1$s = plugin name(s).
            'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', TR_THEMENAMEOPTIONS), // %1$s = plugin name(s).
            'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins', TR_THEMENAMEOPTIONS),
            'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins', TR_THEMENAMEOPTIONS),
            'return'                          => __( 'Return to Required Plugins Installer', TR_THEMENAMEOPTIONS),
            'plugin_activated'                => __( 'Plugin activated successfully.', TR_THEMENAMEOPTIONS),
            'complete'                        => __( 'All plugins installed and activated successfully. %s', TR_THEMENAMEOPTIONS), // %s = dashboard link.
            'nag_type'                        => 'updated', // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
            'dismiss'                        => __( 'Dismiss this notice', TR_THEMENAMEOPTIONS),
			'activated_successfully'         => __( 'The following plugin was activated successfully:', 'tgmpa' ),
        )
    );

    tgmpa( $plugins, $config );

}